@@ -2,7 +2,7 @@
 
    GNU Chess engine
 
-   Copyright (C) 2001-2011 Free Software Foundation, Inc.
+   Copyright (C) 2001-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
+#include <pthread.h>
 
 #include "board.h"
 #include "book.h"
@@ -207,7 +208,8 @@ static void loop_step() {
       ASSERT(!Searching);
       ASSERT(!Delay);
 
-      exit(EXIT_SUCCESS);
+      //exit(EXIT_SUCCESS);
+      pthread_exit(NULL);
 
    } else if (string_start_with(string,"setoption ")) {
 
