@@ -37,6 +37,8 @@
 #include "frontend/common.h"
 #include "gettext.h"
 
+#define _(str) gettext (str)
+
 unsigned char lzArray[65536];
 BitBoard BitPosArray[64];
 BitBoard NotBitPosArray[64];
@@ -312,7 +314,7 @@ int main (int argc, char *argv[])
        errno = 0; /* zero error indicator */
        opt_memory = strtol (optarg, &endptr, 10);
        if ( errno != 0 || *endptr != '\0' ){
-         printf("Memory out of Range or Invalid\n");
+         printf(_("Memory out of Range or Invalid\n"));
          return(1);
        }
        break;
@@ -329,13 +331,13 @@ int main (int argc, char *argv[])
        }
        errno = 0; /* zero error indicator */
        if ( strlen( optarg ) > MAXSTR ) {
-         printf( "File name is too long (max = %d)\n", MAXSTR );
+         printf( _("File name is too long (max = %d)\n"), MAXSTR );
          return(1);
        }
        strcpy( opt_addbook, optarg );
        break;
      default:
-       puts ("Option Processing Failed\n");
+       puts (_("Option Processing Failed\n"));
        abort();
      }
   } /* end of getopt_long style parsing */
@@ -376,10 +378,12 @@ int main (int argc, char *argv[])
 
   /* Startup output */
   if ( !( flags & XBOARD ) && ( !opt_quiet ) && ( !opt_uci) ) {
-    printf( "Copyright (C) 2015 Free Software Foundation, Inc.\n" );
-    printf( "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n" );
-    printf( "This is free software: you are free to change and redistribute it.\n" );
-    printf( "There is NO WARRANTY, to the extent permitted by law.\n" );
+    printf ( _("\
+Copyright (C) %s Free Software Foundation, Inc.\n\
+License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
+This is free software: you are free to change and redistribute it.\n\
+There is NO WARRANTY, to the extent permitted by law.\n"),
+             "2015" );
   }
 
   /* If a usage statement is required output it here */
@@ -487,7 +491,7 @@ int main (int argc, char *argv[])
       NextUserCmd();
       /* Show thinking message */
       if ((flags & THINK) && !(flags & MANUAL) && !(flags & ENDED)) {
-        if (!(flags & XBOARD)) printf("Thinking...\n");
+        if (!(flags & XBOARD)) printf(_("Thinking...\n"));
         CLEAR (flags, THINK);
       }
       /* Check if there is a new command from the engine */
@@ -502,5 +506,9 @@ int main (int argc, char *argv[])
   }
 
   dbg_close();
+
+  /* Termintate adapter and engine threads and join them */
+  TerminateAdapterEngine();
+  
   return (0);
 }
